import logging
import os
import os.path as osp
import shutil

import hydra
from hydra import compose, initialize
from omegaconf import DictConfig, OmegaConf

# set logger
log = logging.getLogger(__name__)

# Put here for logging to terminal... Need to check regular python logging
@hydra.main(version_base=None, config_path="conf", config_name="config_template")
def main(cfg):
    if not osp.exists("zendron/conf/config.yaml"):
        log.info("Initializing config.yaml")
        shutil.copyfile("zendron/conf/config_template.yaml", "zendron/conf/config.yaml")
    else:
        log.info("Already initialized config.yaml")


if __name__ == "__main__":
    main()



import logging
import subprocess

from zendron import load

log = logging.getLogger(__name__)


def main():
    log.info("Sync Starting")
    load.main()
    subprocess.run("dendron importPod --podId dendron.markdown --wsRoot .", shell=True)
    subprocess.run("rm -r zotero_pod", shell=True)
    log.info("Sync Complete")


if __name__ == "__main__":
    main()


import shutil

directory_to_remove = "/path/to/directory"

try:
    shutil.rmtree(directory_to_remove)
    print(f"Directory '{directory_to_remove}' and its contents have been removed.")
except OSError as e:
    print(f"Error: {e.filename} - {e.strerror}.")
